@@ -325,7 +325,7 @@ static int MainHeadSize;
 
 static long CurBlockPos,NextBlockPos;
 
-static unsigned long CurUnpRead, CurUnpWrite;
+static unsigned long CurUnpRead;
 static long UnpPackedSize;
 static long DestUnpSize;
 
@@ -344,7 +344,7 @@ static int ReadHeader(int BlockType);
 static BOOL ExtrFile(int desc);
 static int tread(void *stream,void *buf,unsigned len);
 static int tseek(void *stream,long offset,int fromwhere);
-static BOOL UnstoreFile(void);
+/* static BOOL UnstoreFile(void); */
 static int IsArchive(void);
 static int ReadBlock(int BlockType);
 static unsigned int UnpRead(unsigned char *Addr,unsigned int Count);
@@ -535,7 +535,7 @@ int urarlib_list(int desc, ArchiveList_struct *list)
 #endif
   (*(DWORD*)list) = (DWORD)NULL;            /* init file list               */
   /* do while file is not extracted and there's no error                    */
-  while (TRUE)
+  for(;;)
   {
     int ReadBlockResult;
     if ((ReadBlockResult = ReadBlock(FILE_HEAD | READSUBBLOCK)) <= 0) /* read name of the next  */
@@ -1037,7 +1037,7 @@ BOOL ExtrFile(int desc)
         break;                              /* error, can't extract file!   */
       }
 
-      CurUnpRead=CurUnpWrite=0;
+      CurUnpRead=0;
       if ((*Password!=0) && (NewLhd.Flags & LHD_PASSWORD))
         Encryption=NewLhd.UnpVer;
       else
@@ -1250,6 +1250,7 @@ int stricomp(char *Str1,char *Str2)
  * ** unpack stored RAR files **
  * *****************************/
 
+/*
 BOOL UnstoreFile(void)
 {
   if ((long)(*temp_output_buffer_offset=UnpRead(temp_output_buffer,
@@ -1260,8 +1261,7 @@ BOOL UnstoreFile(void)
   }
   return TRUE;
 }
-
-
+*/
 
 
 /* ****************************************
